"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getGqlFetch = void 0;
// @ts-check
const defaults = {
  apiUrl: null,
  handleBadStatusResponse: response => response,
  firstCatch: err => {
    throw err;
  },
  getToken: () => null
};
/**
 * @param {{
 *   apiUrl?: string
 *   handleBadStatusResponse?: function
 *   firstCatch?: (Error) => any
 *   getToken?: () => string
 * }} options
 * @returns {(query: string, variables: any) => Promise}
 */

const getGqlFetch = options => (query, variables = null) => {
  const opts = Object.assign({}, defaults, options);
  const token = opts.getToken();
  const encodedQuery = encodeURIComponent(query.trim());
  const encodedVars = variables ? "&variables=".concat(encodeURIComponent(JSON.stringify(variables))) : '';
  const tokenQuery = token ? "&token=".concat(token) : '';
  return fetch("".concat(opts.apiUrl, "/graphql?query=").concat(encodedQuery).concat(encodedVars).concat(tokenQuery), {
    method: 'post'
  }).then(response => response.json()).then(parsed => {
    if (parsed.errors) {
      parsed.errors.forEach(error => {
        if ((error.message === 'NO_AUTH' || error.message === 'NO_USER') && opts.handleBadStatusResponse) {
          opts.handleBadStatusResponse();
        }
      });
      throw parsed.errors;
    }

    return parsed;
  });
};

exports.getGqlFetch = getGqlFetch;